@@ -1,5 +1,5 @@
-hbootindex <- 
-function(groups, strata, B = 199) 
+hbootindex <-
+function(groups, strata, B = 199)
 {
     groups <- as.integer(as.factor(as.integer(groups)))
     n <- length(groups)
@@ -23,15 +23,12 @@ function(groups, strata, B = 199)
             w0 <- table(g)
             w <- w0[match(g, names(w0))]
             w <- w / sum(w)
-            out[[j]] <- sample(ni[strata==j], length(g), 
-                replace=TRUE, prob=w)
+            vec <- ni[strata == j]
+            out[[j]] <- if (length(vec) < 2)
+                vec else sample(vec, length(g), replace = TRUE, prob = w)
         }
         out <- unlist(out)
         sample(out, length(out), replace=FALSE)
     }
-    if (require(pbapply)) {
-        pbsapply(1:(B+1), xyclboot)
-    } else {
-        sapply(1:(B+1), xyclboot)
-    }
+    pbapply::pbsapply(1:(B+1), xyclboot)
 }
