@@ -4,10 +4,15 @@ function (object, n.imp = 0, ...)
     if (inherits(object, "svocc")) {
         rval <- fitted(object)
     } else {
+        stop("not yet implemented for abundance models")
         z1 <- 1 - object$zif.probabilities
         p1 <- 1 - exp(-fitted(object))
         obs01 <- ifelse(object$y > 0, 1, 0)
-        rval <- pmax(obs01, z1 * p1)
+        phi <- z1 * p1
+        #delta <- object$detection.probabilities
+        #Py1w0 <- (phi * (1 - delta))/((1 - phi) + (phi * (1 - delta)))
+        rval <- pmax(obs01, phi)
+        #rval <- pmax(obs01, Py1w0)
     }
     if (n.imp) {
         rval <- rbinom(length(object$y) * n.imp, 1, rval)
