@@ -3,7 +3,7 @@
 .onAttach <- function(libname, pkgname){
     ver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
                     fields=c("Version", "Date"))
-    packageStartupMessage(paste(pkgname, ver[1], "\t", ver[2], "\n"))
+    packageStartupMessage(paste(pkgname, ver[1], "\t", ver[2]))
     invisible(NULL)
 }
 
